@@ -23,9 +23,9 @@
 
 import threading
 import unittest
-import monetdbe as monetdbe
+from test.support import TESTFN, rmtree
 
-from test.support import TESTFN, unlink
+import monetdbe as monetdbe
 
 
 class ModuleTests(unittest.TestCase):
@@ -96,11 +96,9 @@ class ConnectionTests(unittest.TestCase):
     def tearDown(self):
         self.cx.close()
 
-    @unittest.skip("TODO (gijs): Not yet implemented")
     def test_Commit(self):
         self.cx.commit()
 
-    @unittest.skip("TODO (gijs): Not yet implemented")
     def test_CommitAfterNoChanges(self):
         """
         A commit should also work when no changes were made to the database.
@@ -108,11 +106,9 @@ class ConnectionTests(unittest.TestCase):
         self.cx.commit()
         self.cx.commit()
 
-    @unittest.skip("TODO (gijs): Not yet implemented")
     def test_Rollback(self):
         self.cx.rollback()
 
-    @unittest.skip("TODO (gijs): Not yet implemented")
     def test_RollbackAfterNoChanges(self):
         """
         A rollback should also work when no changes were made to the database.
@@ -144,14 +140,13 @@ class ConnectionTests(unittest.TestCase):
         self.assertEqual(self.cx.ProgrammingError, monetdbe.ProgrammingError)
         self.assertEqual(self.cx.NotSupportedError, monetdbe.NotSupportedError)
 
-    @unittest.skip("TODO (gijs): Not yet implemented")
     def test_InTransaction(self):
         # Can't use db from setUp because we want to test initial state.
         cx = monetdbe.connect(":memory:")
         cu = cx.cursor()
         self.assertEqual(cx.in_transaction, False)
-        cu.execute("create table transactiontest(id integer primary key, name text)")
-        self.assertEqual(cx.in_transaction, False)
+        cu.execute("create table transactiontest(id integer auto_increment primary key, name text)")
+        self.assertEqual(cx.in_transaction, True)
         cu.execute("insert into transactiontest(name) values (?)", ("foo",))
         self.assertEqual(cx.in_transaction, True)
         cu.execute("select name from transactiontest where name=?", ["foo"])
@@ -161,7 +156,7 @@ class ConnectionTests(unittest.TestCase):
         self.assertEqual(cx.in_transaction, False)
         cu.execute("select name from transactiontest where name=?", ["foo"])
         row = cu.fetchone()
-        self.assertEqual(cx.in_transaction, False)
+        self.assertEqual(cx.in_transaction, True)
 
     def test_InTransactionRO(self):
         with self.assertRaises(AttributeError):
@@ -170,7 +165,7 @@ class ConnectionTests(unittest.TestCase):
     def test_OpenWithPathLikeObject(self):
         """ Checks that we can successfully connect to a database using an object that
             is PathLike, i.e. has __fspath__(). """
-        self.addCleanup(unlink, TESTFN)
+        self.addCleanup(rmtree, TESTFN)
 
         class Path:
             def __fspath__(self):
@@ -180,9 +175,9 @@ class ConnectionTests(unittest.TestCase):
         with monetdbe.connect(path) as cx:
             cx.execute('create table test(id integer)')
 
-    @unittest.skip("TODO (gijs): Not yet implemented")
+    @unittest.skip("TODO: Not yet implemented, see issue #22")
     def test_OpenUri(self):
-        self.addCleanup(unlink, TESTFN)
+        self.addCleanup(rmtree, TESTFN)
         with monetdbe.connect(TESTFN) as cx:
             cx.execute('create table test(id integer)')
         with monetdbe.connect('file:' + TESTFN, uri=True) as cx:
@@ -244,6 +239,7 @@ class CursorTests(unittest.TestCase):
     def test_ExecuteArgString(self):
         self.cu.execute("insert into test(name) values (?)", ("Hugo",))
 
+    @unittest.skip("todo: not yet supported, see issue #21")
     def test_ExecuteArgStringWithZeroByte(self):
         self.cu.execute("insert into test(name) values (?)", ("Hu\x00go",))
 
@@ -332,6 +328,7 @@ class CursorTests(unittest.TestCase):
         self.cu.execute("update test set name='bar'")
         self.assertEqual(self.cu.rowcount, 2)
 
+    @unittest.skip("we skip this test, since we actually *do* know the rowcount")
     def test_RowcountSelect(self):
         """
         pymonetdbe does not know the rowcount of SELECT statements, because we
@@ -467,18 +464,20 @@ class CursorTests(unittest.TestCase):
 
     def test_WrongCursorCallable(self):
         with self.assertRaises(TypeError):
-            def f(): pass
+            def f():
+                ...
 
             cur = self.cx.cursor(f)
 
     def test_CursorWrongClass(self):
-        class Foo: pass
+        class Foo:
+            ...
 
         foo = Foo()
         with self.assertRaises(TypeError):
             cur = monetdbe.Cursor(foo)
 
-    @unittest.skip("TODO: (gijs) this crashes monetdb")
+    @unittest.skip("monetdb doesn't support INSERT OR REPLACE")
     def test_LastRowIDOnReplace(self):
         """
         INSERT OR REPLACE and REPLACE INTO should produce the same behavior.
@@ -489,6 +488,7 @@ class CursorTests(unittest.TestCase):
                 self.cu.execute(sql.format(statement), (1, 'foo'))
                 self.assertEqual(self.cu.lastrowid, 1)
 
+    @unittest.skip("skipping this test, we don't support 'insert or '")
     def test_LastRowIDOnIgnore(self):
         self.cu.execute(
             "insert or ignore into test(unique_test) values (?)",
@@ -499,7 +499,7 @@ class CursorTests(unittest.TestCase):
             ('test',))
         self.assertEqual(self.cu.lastrowid, 2)
 
-    @unittest.skip("TODO: (gijs) this crashes monetdb")
+    @unittest.skip("skipping this test, we don't support 'insert or '")
     def test_LastRowIDInsertOR(self):
         results = []
         for statement in ('FAIL', 'ABORT', 'ROLLBACK'):
@@ -519,6 +519,7 @@ class CursorTests(unittest.TestCase):
         self.assertEqual(results, expected)
 
 
+@unittest.skip("todo (gijs): for now we dont support or check for multi-threading")
 class ThreadTests(unittest.TestCase):
     def setUp(self):
         self.con = monetdbe.connect(":memory:")
@@ -538,7 +539,7 @@ class ThreadTests(unittest.TestCase):
                 return
             except monetdbe.ProgrammingError:
                 return
-            except:
+            except Exception:
                 errors.append("raised wrong exception")
 
         errors = []
@@ -556,7 +557,7 @@ class ThreadTests(unittest.TestCase):
                 return
             except monetdbe.ProgrammingError:
                 return
-            except:
+            except Exception:
                 errors.append("raised wrong exception")
 
         errors = []
@@ -574,7 +575,7 @@ class ThreadTests(unittest.TestCase):
                 return
             except monetdbe.ProgrammingError:
                 return
-            except:
+            except Exception:
                 errors.append("raised wrong exception")
 
         errors = []
@@ -592,7 +593,7 @@ class ThreadTests(unittest.TestCase):
                 return
             except monetdbe.ProgrammingError:
                 return
-            except:
+            except Exception:
                 errors.append("raised wrong exception")
 
         errors = []
@@ -610,7 +611,7 @@ class ThreadTests(unittest.TestCase):
                 return
             except monetdbe.ProgrammingError:
                 return
-            except:
+            except Exception:
                 errors.append("raised wrong exception")
 
         errors = []
@@ -628,7 +629,7 @@ class ThreadTests(unittest.TestCase):
                 return
             except monetdbe.ProgrammingError:
                 return
-            except:
+            except Exception:
                 errors.append("raised wrong exception")
 
         errors = []
@@ -646,7 +647,7 @@ class ThreadTests(unittest.TestCase):
                 return
             except monetdbe.ProgrammingError:
                 return
-            except:
+            except Exception:
                 errors.append("raised wrong exception")
 
         errors = []
@@ -665,7 +666,7 @@ class ThreadTests(unittest.TestCase):
                 return
             except monetdbe.ProgrammingError:
                 return
-            except:
+            except Exception:
                 errors.append("raised wrong exception")
 
         errors = []
@@ -786,7 +787,8 @@ class ClosedConTests(unittest.TestCase):
         con = monetdbe.connect(":memory:")
         con.close()
 
-        def f(x): return 17
+        def f(x):
+            return 17
 
         with self.assertRaises(monetdbe.ProgrammingError):
             con.create_function("foo", 1, f)
@@ -822,7 +824,8 @@ class ClosedConTests(unittest.TestCase):
         con = monetdbe.connect(":memory:")
         con.close()
 
-        def progress(): pass
+        def progress():
+            pass
 
         with self.assertRaises(monetdbe.ProgrammingError):
             con.set_progress_handler(progress, 100)
@@ -853,6 +856,7 @@ class ClosedCurTests(unittest.TestCase):
                 method(*params)
 
 
+@unittest.skip("We don't support INSERT OR syntax")
 class monetdbeOnConflictTests(unittest.TestCase):
     """
     Tests for monetdbe's "insert on conflict" feature.
